@@ -79,6 +79,7 @@ try:
 
     import ebltable.tau_from_model as ebltau
 
+    has_ebltable = True
 
 except ImportError:
 
@@ -87,9 +88,12 @@ except ImportError:
 
     has_ebltable = False
 
-else:
+except:
 
-    has_ebltable = True
+    has_ebltable = False
+
+    warnings.warn("The ebltable package is broken",
+                  EBLTableNotAvailable)
 
 
 # noinspection PyPep8Naming
@@ -334,6 +338,7 @@ class Cutoff_powerlaw(Function1D):
 
         return K * np.exp(log_v)
 
+@six.add_metaclass(FunctionMeta)
 class Inverse_cutoff_powerlaw(Function1D):
     r"""
     description :
@@ -362,7 +367,7 @@ class Inverse_cutoff_powerlaw(Function1D):
             initial value : 1
     """
 
-    __metaclass__ = FunctionMeta
+
 
     def _set_units(self, x_unit, y_unit):
         # The index is always dimensionless
