@@ -4,9 +4,11 @@ import pytest
 import os
 import numpy as np
 
-from astromodels.functions.template_model import TemplateModel, TemplateModelFactory, MissingDataFile
+from astromodels.functions.template_model import TemplateModel, TemplateModelFactory, MissingDataFile, XSPECTableModel
 from astromodels.functions.functions import Band, Powerlaw
 from astromodels import Model, PointSource, clone_model, load_model
+from astromodels.utils.data_files import _get_data_file_path
+
 import pickle
 
 __author__ = 'giacomov'
@@ -190,3 +192,10 @@ def test_input_output():
 
     os.remove("__test.yml")
 
+def test_xspec_table_model():
+
+    test_table = _get_data_file_path("tests/test_xspec_table_model.fits")
+
+    xtm = XSPECTableModel(test_table)
+
+    xtm.to_table_model('xspectm_test', 'xspec model')
